@@ -664,7 +664,7 @@ htp_status_t htp_connp_REQ_HEADERS(htp_connp_t *connp) {
 
                 IN_PEEK_NEXT(connp);
 
-                if (htp_is_folding_char(connp->in_next_byte) == 0) {
+                if (connp->in_next_byte != -1 && htp_is_folding_char(connp->in_next_byte) == 0) {
                     // Because we know this header is not folded, we can process the buffer straight away.
                     if (connp->cfg->process_request_header(connp, data, len) != HTP_OK) return HTP_ERROR;
                 } else {
